% Intrinsic and Extrinsic Camera Parameters
%
% This script file can be directly excecuted under Matlab to recover the camera intrinsic and extrinsic parameters.
% IMPORTANT: This file contains neither the structure of the calibration objects nor the image coordinates of the calibration points.
%            All those complementary variables are saved in the complete matlab data file Calib_Results.mat.
% For more information regarding the calibration model visit http://www.vision.caltech.edu/bouguetj/calib_doc/


%-- Focal length:
fc = [ 380.158573619842510 ; 377.576889048121980 ];

%-- Principal point:
cc = [ 301.361675180538950 ; 390.194394652916400 ];

%-- Skew coefficient:
alpha_c = 0.000000000000000;

%-- Distortion coefficients:
kc = [ -0.232065706566837 ; 0.054559524294382 ; -0.000485724437114 ; -0.000051227090558 ; 0.000000000000000 ];

%-- Focal length uncertainty:
fc_error = [ 1.238426360186601 ; 0.785516621703410 ];

%-- Principal point uncertainty:
cc_error = [ 1.079773582794481 ; 1.175476837435553 ];

%-- Skew coefficient uncertainty:
alpha_c_error = 0.000000000000000;

%-- Distortion coefficients uncertainty:
kc_error = [ 0.001524623135910 ; 0.000947592621766 ; 0.000365781703584 ; 0.000251378037295 ; 0.000000000000000 ];

%-- Image size:
nx = 615;
ny = 809;


%-- Various other variables (may be ignored if you do not use the Matlab Calibration Toolbox):
%-- Those variables are used to control which intrinsic parameters should be optimized

n_ima = 50;						% Number of calibration images
est_fc = [ 1 ; 1 ];					% Estimation indicator of the two focal variables
est_aspect_ratio = 1;				% Estimation indicator of the aspect ratio fc(2)/fc(1)
center_optim = 1;					% Estimation indicator of the principal point
est_alpha = 0;						% Estimation indicator of the skew coefficient
est_dist = [ 1 ; 1 ; 1 ; 1 ; 0 ];	% Estimation indicator of the distortion coefficients


%-- Extrinsic parameters:
%-- The rotation (omc_kk) and the translation (Tc_kk) vectors for every calibration image and their uncertainties

%-- Image #1:
omc_1 = [ NaN ; NaN ; NaN ];
Tc_1  = [ NaN ; NaN ; NaN ];
omc_error_1 = [ NaN ; NaN ; NaN ];
Tc_error_1  = [ NaN ; NaN ; NaN ];

%-- Image #2:
omc_2 = [ 1.743444e+000 ; 1.652685e+000 ; 5.366907e-001 ];
Tc_2  = [ 2.676669e+001 ; -4.052367e+002 ; 9.091003e+002 ];
omc_error_2 = [ 3.298456e-003 ; 2.785274e-003 ; 4.197172e-003 ];
Tc_error_2  = [ 2.735734e+000 ; 2.857572e+000 ; 2.727326e+000 ];

%-- Image #3:
omc_3 = [ NaN ; NaN ; NaN ];
Tc_3  = [ NaN ; NaN ; NaN ];
omc_error_3 = [ NaN ; NaN ; NaN ];
Tc_error_3  = [ NaN ; NaN ; NaN ];

%-- Image #4:
omc_4 = [ 1.606973e+000 ; 1.496193e+000 ; 7.212490e-001 ];
Tc_4  = [ -3.618835e+002 ; -4.004038e+002 ; 9.200577e+002 ];
omc_error_4 = [ 3.012604e-003 ; 2.913704e-003 ; 4.094957e-003 ];
Tc_error_4  = [ 2.800598e+000 ; 2.991862e+000 ; 2.954279e+000 ];

%-- Image #5:
omc_5 = [ 1.490986e+000 ; 1.368106e+000 ; 8.452523e-001 ];
Tc_5  = [ -4.018052e+002 ; -4.011169e+002 ; 8.554643e+002 ];
omc_error_5 = [ 2.885354e-003 ; 2.840520e-003 ; 3.744631e-003 ];
Tc_error_5  = [ 2.680886e+000 ; 2.824893e+000 ; 2.865244e+000 ];

%-- Image #6:
omc_6 = [ NaN ; NaN ; NaN ];
Tc_6  = [ NaN ; NaN ; NaN ];
omc_error_6 = [ NaN ; NaN ; NaN ];
Tc_error_6  = [ NaN ; NaN ; NaN ];

%-- Image #7:
omc_7 = [ NaN ; NaN ; NaN ];
Tc_7  = [ NaN ; NaN ; NaN ];
omc_error_7 = [ NaN ; NaN ; NaN ];
Tc_error_7  = [ NaN ; NaN ; NaN ];

%-- Image #8:
omc_8 = [ NaN ; NaN ; NaN ];
Tc_8  = [ NaN ; NaN ; NaN ];
omc_error_8 = [ NaN ; NaN ; NaN ];
Tc_error_8  = [ NaN ; NaN ; NaN ];

%-- Image #9:
omc_9 = [ -1.969121e+000 ; -2.007040e+000 ; 7.258756e-001 ];
Tc_9  = [ -9.163007e+002 ; -3.704572e+002 ; 1.473529e+003 ];
omc_error_9 = [ 3.772886e-003 ; 2.622074e-003 ; 5.334904e-003 ];
Tc_error_9  = [ 4.657576e+000 ; 5.058851e+000 ; 4.373364e+000 ];

%-- Image #10:
omc_10 = [ -1.828346e+000 ; -1.887956e+000 ; 8.691967e-001 ];
Tc_10  = [ -5.388752e+002 ; -3.771344e+002 ; 1.441787e+003 ];
omc_error_10 = [ 3.460961e-003 ; 2.553278e-003 ; 4.814747e-003 ];
Tc_error_10  = [ 4.248339e+000 ; 4.671435e+000 ; 3.643017e+000 ];

%-- Image #11:
omc_11 = [ -1.673099e+000 ; -1.753691e+000 ; 1.005808e+000 ];
Tc_11  = [ 1.943278e+002 ; -3.839051e+002 ; 1.494777e+003 ];
omc_error_11 = [ 3.482500e-003 ; 2.725370e-003 ; 5.146980e-003 ];
Tc_error_11  = [ 4.432714e+000 ; 4.698333e+000 ; 3.426489e+000 ];

%-- Image #12:
omc_12 = [ -1.538178e+000 ; -1.625862e+000 ; 1.112178e+000 ];
Tc_12  = [ 2.232454e+002 ; -3.881678e+002 ; 1.431564e+003 ];
omc_error_12 = [ 3.316418e-003 ; 2.425729e-003 ; 4.467885e-003 ];
Tc_error_12  = [ 4.276939e+000 ; 4.524398e+000 ; 3.134108e+000 ];

%-- Image #13:
omc_13 = [ NaN ; NaN ; NaN ];
Tc_13  = [ NaN ; NaN ; NaN ];
omc_error_13 = [ NaN ; NaN ; NaN ];
Tc_error_13  = [ NaN ; NaN ; NaN ];

%-- Image #14:
omc_14 = [ -1.632742e+000 ; -1.716026e+000 ; 1.054037e+000 ];
Tc_14  = [ 1.101160e+002 ; -1.719588e+002 ; 1.209543e+003 ];
omc_error_14 = [ 2.931126e-003 ; 2.480018e-003 ; 4.449582e-003 ];
Tc_error_14  = [ 3.510643e+000 ; 3.752062e+000 ; 2.410679e+000 ];

%-- Image #15:
omc_15 = [ -1.742122e+000 ; -1.803094e+000 ; 9.597021e-001 ];
Tc_15  = [ -1.667640e+002 ; -1.746061e+002 ; 1.086588e+003 ];
omc_error_15 = [ 2.928260e-003 ; 2.389011e-003 ; 4.421514e-003 ];
Tc_error_15  = [ 3.070900e+000 ; 3.382527e+000 ; 2.231240e+000 ];

%-- Image #16:
omc_16 = [ NaN ; NaN ; NaN ];
Tc_16  = [ NaN ; NaN ; NaN ];
omc_error_16 = [ NaN ; NaN ; NaN ];
Tc_error_16  = [ NaN ; NaN ; NaN ];

%-- Image #17:
omc_17 = [ NaN ; NaN ; NaN ];
Tc_17  = [ NaN ; NaN ; NaN ];
omc_error_17 = [ NaN ; NaN ; NaN ];
Tc_error_17  = [ NaN ; NaN ; NaN ];

%-- Image #18:
omc_18 = [ -1.973994e+000 ; -1.996560e+000 ; 7.211659e-001 ];
Tc_18  = [ -6.581476e+002 ; -1.713195e+002 ; 1.030848e+003 ];
omc_error_18 = [ 3.385012e-003 ; 2.453458e-003 ; 4.845344e-003 ];
Tc_error_18  = [ 3.094118e+000 ; 3.530152e+000 ; 2.868610e+000 ];

%-- Image #19:
omc_19 = [ NaN ; NaN ; NaN ];
Tc_19  = [ NaN ; NaN ; NaN ];
omc_error_19 = [ NaN ; NaN ; NaN ];
Tc_error_19  = [ NaN ; NaN ; NaN ];

%-- Image #20:
omc_20 = [ -1.969092e+000 ; -1.994475e+000 ; 7.314410e-001 ];
Tc_20  = [ -8.031275e+002 ; -1.679988e+002 ; 1.035522e+003 ];
omc_error_20 = [ 3.499372e-003 ; 2.595170e-003 ; 4.806928e-003 ];
Tc_error_20  = [ 3.269416e+000 ; 3.706336e+000 ; 3.148993e+000 ];

%-- Image #21:
omc_21 = [ NaN ; NaN ; NaN ];
Tc_21  = [ NaN ; NaN ; NaN ];
omc_error_21 = [ NaN ; NaN ; NaN ];
Tc_error_21  = [ NaN ; NaN ; NaN ];

%-- Image #22:
omc_22 = [ 1.668895e+000 ; 1.541575e+000 ; 6.598720e-001 ];
Tc_22  = [ -6.137058e+002 ; -1.768563e+002 ; 8.437338e+002 ];
omc_error_22 = [ 2.967815e-003 ; 3.108920e-003 ; 4.749316e-003 ];
Tc_error_22  = [ 2.819656e+000 ; 2.935947e+000 ; 2.864133e+000 ];

%-- Image #23:
omc_23 = [ 1.571555e+000 ; 1.425114e+000 ; 7.560868e-001 ];
Tc_23  = [ -3.226277e+002 ; -1.852378e+002 ; 7.172122e+002 ];
omc_error_23 = [ 2.952258e-003 ; 2.425409e-003 ; 3.780443e-003 ];
Tc_error_23  = [ 2.139931e+000 ; 2.323199e+000 ; 2.233271e+000 ];

%-- Image #24:
omc_24 = [ 1.563805e+000 ; 1.428194e+000 ; 7.705572e-001 ];
Tc_24  = [ -7.870389e+001 ; -1.899216e+002 ; 6.951379e+002 ];
omc_error_24 = [ 3.216911e-003 ; 2.407961e-003 ; 3.515923e-003 ];
Tc_error_24  = [ 1.997306e+000 ; 2.156031e+000 ; 2.073863e+000 ];

%-- Image #25:
omc_25 = [ NaN ; NaN ; NaN ];
Tc_25  = [ NaN ; NaN ; NaN ];
omc_error_25 = [ NaN ; NaN ; NaN ];
Tc_error_25  = [ NaN ; NaN ; NaN ];

%-- Image #26:
omc_26 = [ NaN ; NaN ; NaN ];
Tc_26  = [ NaN ; NaN ; NaN ];
omc_error_26 = [ NaN ; NaN ; NaN ];
Tc_error_26  = [ NaN ; NaN ; NaN ];

%-- Image #27:
omc_27 = [ 1.769268e+000 ; 1.667271e+000 ; 5.174114e-001 ];
Tc_27  = [ 9.708116e+001 ; -1.878269e+002 ; 8.162717e+002 ];
omc_error_27 = [ 3.412675e-003 ; 2.452932e-003 ; 4.262803e-003 ];
Tc_error_27  = [ 2.421096e+000 ; 2.536982e+000 ; 2.293685e+000 ];

%-- Image #28:
omc_28 = [ NaN ; NaN ; NaN ];
Tc_28  = [ NaN ; NaN ; NaN ];
omc_error_28 = [ NaN ; NaN ; NaN ];
Tc_error_28  = [ NaN ; NaN ; NaN ];

%-- Image #29:
omc_29 = [ 1.931941e+000 ; 1.865390e+000 ; 2.472818e-001 ];
Tc_29  = [ 3.302994e+002 ; -1.917747e+002 ; 7.449906e+002 ];
omc_error_29 = [ 3.701977e-003 ; 2.580522e-003 ; 5.354239e-003 ];
Tc_error_29  = [ 2.517094e+000 ; 2.423721e+000 ; 2.120815e+000 ];

%-- Image #30:
omc_30 = [ 1.875896e+000 ; 1.719417e+000 ; 1.755501e-001 ];
Tc_30  = [ -5.053081e+002 ; 4.236646e+001 ; 6.243415e+002 ];
omc_error_30 = [ 2.726453e-003 ; 2.715589e-003 ; 5.004694e-003 ];
Tc_error_30  = [ 2.003476e+000 ; 2.243226e+000 ; 2.158306e+000 ];

%-- Image #31:
omc_31 = [ NaN ; NaN ; NaN ];
Tc_31  = [ NaN ; NaN ; NaN ];
omc_error_31 = [ NaN ; NaN ; NaN ];
Tc_error_31  = [ NaN ; NaN ; NaN ];

%-- Image #32:
omc_32 = [ 1.819071e+000 ; 1.641998e+000 ; 2.970043e-001 ];
Tc_32  = [ -2.109321e+002 ; 3.686074e+001 ; 6.394106e+002 ];
omc_error_32 = [ 3.170909e-003 ; 1.947688e-003 ; 4.581177e-003 ];
Tc_error_32  = [ 1.838086e+000 ; 2.033080e+000 ; 1.649769e+000 ];

%-- Image #33:
omc_33 = [ 1.822972e+000 ; 1.654106e+000 ; 2.796856e-001 ];
Tc_33  = [ 5.734813e+001 ; 3.424300e+001 ; 6.008294e+002 ];
omc_error_33 = [ 3.382740e-003 ; 1.815455e-003 ; 4.813300e-003 ];
Tc_error_33  = [ 1.764095e+000 ; 1.875289e+000 ; 1.495927e+000 ];

%-- Image #34:
omc_34 = [ -1.837008e+000 ; -1.991892e+000 ; 1.001361e+000 ];
Tc_34  = [ -1.569788e+001 ; 4.712853e+001 ; 9.519975e+002 ];
omc_error_34 = [ 2.402394e-003 ; 2.977600e-003 ; 4.787210e-003 ];
Tc_error_34  = [ 2.673505e+000 ; 2.952956e+000 ; 2.136987e+000 ];

%-- Image #35:
omc_35 = [ -1.852794e+000 ; -2.002001e+000 ; 9.909594e-001 ];
Tc_35  = [ -1.383050e+002 ; 5.104049e+001 ; 9.918440e+002 ];
omc_error_35 = [ 2.558727e-003 ; 2.893019e-003 ; 4.822870e-003 ];
Tc_error_35  = [ 2.761791e+000 ; 3.103850e+000 ; 2.120176e+000 ];

%-- Image #36:
omc_36 = [ -1.846348e+000 ; -1.991416e+000 ; 9.949830e-001 ];
Tc_36  = [ -3.497655e+002 ; 5.417075e+001 ; 1.033230e+003 ];
omc_error_36 = [ 2.846722e-003 ; 2.776911e-003 ; 4.681565e-003 ];
Tc_error_36  = [ 2.893448e+000 ; 3.329438e+000 ; 2.268914e+000 ];

%-- Image #37:
omc_37 = [ -1.879422e+000 ; -2.012767e+000 ; 9.675749e-001 ];
Tc_37  = [ -5.339454e+002 ; 5.427738e+001 ; 9.557813e+002 ];
omc_error_37 = [ 3.094927e-003 ; 2.808704e-003 ; 4.547829e-003 ];
Tc_error_37  = [ 2.764914e+000 ; 3.234176e+000 ; 2.386144e+000 ];

%-- Image #38:
omc_38 = [ -2.054628e+000 ; -2.132031e+000 ; 8.054710e-001 ];
Tc_38  = [ -6.387710e+002 ; 5.357879e+001 ; 9.038380e+002 ];
omc_error_38 = [ 3.298010e-003 ; 2.784883e-003 ; 5.070781e-003 ];
Tc_error_38  = [ 2.679021e+000 ; 3.193158e+000 ; 2.643086e+000 ];

%-- Image #39:
omc_39 = [ NaN ; NaN ; NaN ];
Tc_39  = [ NaN ; NaN ; NaN ];
omc_error_39 = [ NaN ; NaN ; NaN ];
Tc_error_39  = [ NaN ; NaN ; NaN ];

%-- Image #40:
omc_40 = [ -2.052675e+000 ; -2.078993e+000 ; 6.952150e-001 ];
Tc_40  = [ -5.392679e+002 ; -8.158419e+002 ; 1.207435e+003 ];
omc_error_40 = [ 4.167427e-003 ; 2.002865e-003 ; 5.793901e-003 ];
Tc_error_40  = [ 3.947243e+000 ; 4.172806e+000 ; 4.059063e+000 ];

%-- Image #41:
omc_41 = [ -2.006631e+000 ; -2.042943e+000 ; 7.569990e-001 ];
Tc_41  = [ -2.797537e+002 ; -8.166896e+002 ; 1.236327e+003 ];
omc_error_41 = [ 4.272815e-003 ; 2.238756e-003 ; 5.432990e-003 ];
Tc_error_41  = [ 3.943279e+000 ; 4.073011e+000 ; 3.937317e+000 ];

%-- Image #42:
omc_42 = [ -1.827188e+000 ; -1.900256e+000 ; 9.396235e-001 ];
Tc_42  = [ -8.748399e+001 ; -8.161655e+002 ; 1.250288e+003 ];
omc_error_42 = [ 4.233009e-003 ; 2.372197e-003 ; 4.845369e-003 ];
Tc_error_42  = [ 3.976776e+000 ; 4.045621e+000 ; 3.921275e+000 ];

%-- Image #43:
omc_43 = [ -1.844838e+000 ; -1.924229e+000 ; 9.179645e-001 ];
Tc_43  = [ 1.416871e+002 ; -8.229029e+002 ; 1.149047e+003 ];
omc_error_43 = [ 4.495393e-003 ; 2.675739e-003 ; 4.835486e-003 ];
Tc_error_43  = [ 3.762791e+000 ; 3.755297e+000 ; 4.045292e+000 ];

%-- Image #44:
omc_44 = [ NaN ; NaN ; NaN ];
Tc_44  = [ NaN ; NaN ; NaN ];
omc_error_44 = [ NaN ; NaN ; NaN ];
Tc_error_44  = [ NaN ; NaN ; NaN ];

%-- Image #45:
omc_45 = [ NaN ; NaN ; NaN ];
Tc_45  = [ NaN ; NaN ; NaN ];
omc_error_45 = [ NaN ; NaN ; NaN ];
Tc_error_45  = [ NaN ; NaN ; NaN ];

%-- Image #46:
omc_46 = [ 2.102096e+000 ; 2.067538e+000 ; -2.307769e-001 ];
Tc_46  = [ 1.401433e+002 ; -8.302720e+002 ; 1.018406e+003 ];
omc_error_46 = [ 3.791524e-003 ; 3.978078e-003 ; 6.184029e-003 ];
Tc_error_46  = [ 3.496188e+000 ; 3.558086e+000 ; 3.756695e+000 ];

%-- Image #47:
omc_47 = [ 1.930190e+000 ; 1.830811e+000 ; 1.906224e-001 ];
Tc_47  = [ -6.079339e+001 ; -8.334716e+002 ; 8.219923e+002 ];
omc_error_47 = [ 2.950405e-003 ; 3.442610e-003 ; 5.995414e-003 ];
Tc_error_47  = [ 2.903586e+000 ; 2.871055e+000 ; 3.602615e+000 ];

%-- Image #48:
omc_48 = [ 1.757031e+000 ; 1.609221e+000 ; 4.841819e-001 ];
Tc_48  = [ -3.599513e+002 ; -8.313311e+002 ; 7.928630e+002 ];
omc_error_48 = [ 2.673816e-003 ; 3.495796e-003 ; 5.244967e-003 ];
Tc_error_48  = [ 2.848303e+000 ; 2.913327e+000 ; 4.157916e+000 ];

%-- Image #49:
omc_49 = [ 1.702329e+000 ; 1.535786e+000 ; 5.570915e-001 ];
Tc_49  = [ -6.135864e+002 ; -8.249235e+002 ; 8.638604e+002 ];
omc_error_49 = [ 2.615649e-003 ; 3.800509e-003 ; 4.996106e-003 ];
Tc_error_49  = [ 3.395250e+000 ; 3.313281e+000 ; 4.684171e+000 ];

%-- Image #50:
omc_50 = [ NaN ; NaN ; NaN ];
Tc_50  = [ NaN ; NaN ; NaN ];
omc_error_50 = [ NaN ; NaN ; NaN ];
Tc_error_50  = [ NaN ; NaN ; NaN ];

