% nacteme soubor, ktery poskytuje cam calib toolbox
% load file containing camera calibration results

[cameraCalibFile,cameraCalibFilePath]=uigetfile('*.mat',...
    'Select the MCCT calibration file (.mat) of the camera');



calibFile = load(strcat(cameraCalibFilePath,cameraCalibFile));

% zjistime, ktere obrazky byly pouzity pro kalibraci (a existuje k nim tedy
% i popis plochy

% we'll determine which images were used for calibration

active_image_numbers = sort(...
    calibFile.image_numbers(find(calibFile.active_images)));

% nejvetsi cislo u nazvu souboru
% the highest file number
maxFileNum = max(active_image_numbers);

%pripravit vystupni cell a dalsi promenne
%prepare output cell and some temp variables
calibrationPlanes = cell(maxFileNum,1);
Rname = 0;
Tname = 0;
R = 0;
T = 0;
alpha = 0;
theta = 0;
innerIndex = 0;

%projit dodane promenne a hledat roviny
%go through calibration variables
for n = 1:maxFileNum
   
    % pokud nebyl obrazek pouzit, neni k nemu zaznam a preskakujeme
    % if the image was not used we'll skip it
    if(isempty(find(active_image_numbers == n)))
        fprintf('Plane of the image %d skipped\n',n);
        calibrationPlanes{n}.filled = 0;
        calibrationPlanes{n}.alpha = -1;
        calibrationPlanes{n}.theta = -1;
        continue;
    end
    
    % jinak najdeme index, pod kterym s nim toolbox pracoval
    % otherwise, we'll determine index used by the camara calib toolbox
    innerIndex = find(calibFile.image_numbers == n);
    
    % vykrademe lasercamcalib toolbox...
    % Get Rotation matrix and Translation vector corresponding to the
    % camera image
    Rname=strcat('calibFile.Rc_',int2str(innerIndex));
    R=eval(Rname);
    Tname=strcat('calibFile.Tc_',int2str(innerIndex));
    T=eval(Tname);
    
    % R obsahuje rotaci souradneho s. spjateho s rovinou kal. desky vuci
    % soustave kamery, T obsahuje translaci techto soustav
    % vypocteme n1, n2, n3 a d tak ze plati [n1 n2 n3 d]*[x1;x2;x3;1] = 0
    % pro body lezici v teto rovine
    % R contains rotation of the coordinate frame corresponding to the
    % calibration plane, T contains its translation. We'll evaluate
    % n1,n2,n3, and d so the equation [n1 n2 n3 d]*[x1;x2;x3;1] = 0 is true
    % for all points lying in the plane
     
    theta=R(:,3); alpha=T'*theta;
    if(alpha<0)
        theta=-theta; alpha=-alpha;
    end
    
    calibrationPlanes{n}.filled = 1;
    
    % v toolboxu se pocita s rovnici [n1 n2 n3 d]*[x1;x2;x3;-1] = 0
    % pro nase ucely budeme brat alpha zaporne, zaroven delime tisicem,
    % toolbox pracuje defaultne s milimetry
    % toolbox uses equation mentioned above, we'll use a minor modification
    % [n1 n2 n3 d]*[x1;x2;x3;-1] = 0 and also multiply alpha by 0.001 to
    % get from milimeters to meters, which are native unit of the lidar
    calibrationPlanes{n}.alpha = -0.001*alpha;
    calibrationPlanes{n}.theta = theta;
    
    fprintf('Plane of the image %d added.\n',n);
    
    
end

% nacist jmeno vystupu
% load the output file
outputfile = input('Enter the output filename: ','s');
if(isempty(outputfile))
    disp('Nothing entered, aborting.');
    break;
end

fprintf('Writing to %s.mat \n',outputfile);
save(strcat(outputfile,'.mat'),'calibrationPlanes');
clear;

disp('Done');

