
% script postupne nacte soubory s cloudem, rovinami a rotaci a translaci,
% overi nactene soubory, vypocita vzdalenosti odpovidajicich bodu od
% odpovidajicich ploch, vykresli histogramy a pripise stredni hodnotu a
% rozptyl

%script loads files containing points of selected planes, plane
%coordinates originating from camera calibration and finally the
%transformation R,t

%% nacist a zkontrolovat soubory
% load and check files

[tempFileName,tempFilePath]=uigetfile('*.mat',...
    'Select file containing laser points of each plane (.mat)');
    

if (tempFileName == 0)
    return;
end

load(strcat(tempFilePath,tempFileName));
if(~exist('lpointClouds'))
    disp('Selected file does not contain cell lpointClouds, aborting.');
           
    return;
end

[tempFileName,tempFilePath]=uigetfile('*.mat',...
    'Select file containing plane coordinates (.mat)');
    
if (tempFileName == 0)
    return;
end

load(strcat(tempFilePath,tempFileName));
if(~exist('calibrationPlanes'))
    disp('Selected file does not contain cell calibrationPlanes, aborting.');
            
    return;
end

[tempFileName,tempFilePath]=uigetfile('*.mat',...
    'Select file containing R and t (.mat)');
    
if (tempFileName == 0)
    return;
end

load(strcat(tempFilePath,tempFileName));
if(~exist('t') || ~exist('R'))
    disp('Selected file does not contain R or t, aborting.');
    return;
end

%% v poradku, projedeme postupne cells, ktere obsahuji odpovidajici roviny
% a laserove body
%alright, we'll go through all cells, transform laser points using R and t and evaluate
%distances from calibration planes

% index n odpovida cislu udaneho u puvodnich souboru snimku kamery a laseru
% index n corresponds to original filenumber from calibration


tempDistances = 0;
tempTransformed = 0;
allDistances = [];
distMean = 0;
distStdDev = 0;
graphTitle = '';
subfigindex = 1;


for n = 1 : max([length(calibrationPlanes) length(lpointClouds)])
    
    
    % prepare subfig index for plotting
    subfigindex = mod(n,9);
    if (subfigindex == 0)
        subfigindex = 9;
    end
    
   
    % pokud v cells jeden z paru neni naplnen, dvojice se preskakuje(muze
    % se stat, ze v kalibraci kamer nebo rovin byl dany snimek nebo mnozina
    % bodu preskocena)
    
    %it may happen that image or point cloud was excluded from calibration
    if( (calibrationPlanes{n}.filled == 0) || (lpointClouds{n}.filled == 0))
        disp(strcat('Skipping pair number ',sprintf('%d',n)));
        %subfig(3,3,subfigindex,figure('Name',sprintf('Calibration Pair %d unused',n),'NumberTitle','off'));
        continue;
    end
    
    %transformace do soustavy kamery
    %both image and cloud were used, we'll evaluate distances from plane
    %first, transform to the camera frame
    tempTransformed = R * (lpointClouds{n}.points') +...
        repmat(t,[1 size(lpointClouds{n}.points',2)]);
    
    %evaluate distances
    tempDistances = [calibrationPlanes{n}.theta' calibrationPlanes{n}.alpha]...
        * [tempTransformed; ones(1,size(tempTransformed,2))];
    
    %do statistics and plot
    subfig(3,3,subfigindex,figure('Name',sprintf('Calibration Pair %d',n),'NumberTitle','off'));
    hist(tempDistances*1000,100);
    distMean = mean(tempDistances);
    distStdDev = std(tempDistances);
    graphTitle = sprintf('#%d: MEAN= %0.3f mm; DEV= %0.3f mm',n,distMean*1000,distStdDev*1000);
    title(graphTitle);
    xlabel('Distance from calib. plane [mm]');
    ylabel('Number of points [/]');
    
    
    allDistances = [allDistances tempDistances];
    
    
end

    subfig(3,3,9,figure('Name','Overall Error Estimation','NumberTitle','off'));
    hist(allDistances*1000,1000);
    distMean = mean(allDistances);
    distStdDev = std(allDistances);
    graphTitle = sprintf('All: MEAN= %0.3f mm; Dev= %0.3f mm',distMean*1000,distStdDev*1000);
    title(graphTitle);
    xlabel('Distance from calib. plane [mm]');
    ylabel('Number of points [/]');
